@@ -443,8 +443,8 @@ $liste_des_authentifications = [
 // pour specifier les versions de SPIP necessaires
 // il faut s'en tenir a un nombre de decimales fixe
 // ex : 2.0.0, 2.0.0-dev, 2.0.0-beta, 2.0.0-beta2
-$spip_version_branche = '4.2.14';
-define('_SPIP_VERSION_ID', 40214);
+$spip_version_branche = '4.3.0';
+define('_SPIP_VERSION_ID', 40300);
 define('_SPIP_EXTRA_VERSION', '');
 
 // cette version dev accepte tous les plugins compatible avec la version ci-dessous
@@ -504,6 +504,11 @@ spip_initialisation_core(
 	(_DIR_RACINE . _NOM_TEMPORAIRES_ACCESSIBLES)
 );
 
+// timezone
+include_spip('inc/config');
+if ($timezone = lire_config('timezone')) {
+	date_default_timezone_set($timezone);
+}
 
 // chargement des plugins : doit arriver en dernier
 // car dans les plugins on peut inclure inc-version
