@@ -967,3 +967,28 @@ function safe_public_traiter_echap_script_dist($regs, $options) {
 	}
 	return '';
 }
+
+function safe_ecrire_traiter_echap_code_dist($regs, $options) {
+	if (function_exists($f = 'traiter_echap_code') or function_exists($f = $f . '_dist')) {
+		$html = $f($regs, $options);
+		// bloquons les scripts ici avant eventuel echappement si trop suspect (ca evite de declencher echappement complet si une partie sera echappee par interdire scripts)
+		if ($GLOBALS['filtrer_javascript'] <= 0) {
+			$html = interdire_scripts($html);
+		}
+		$html = echapper_html_suspect($html, ['strict' => true, 'wrap_suspect' => "<code class='echappe-js'>"], $options['connect'] ?? '', $options['env'] ?? ['espace_prive' => true]);
+		return $html;
+	}
+	return '';
+}
+
+function safe_public_traiter_echap_code_dist($regs, $options) {
+	if (function_exists($f = 'traiter_echap_code') or function_exists($f = $f . '_dist')) {
+		$html = $f($regs, $options);
+		// bloquons les scripts ou attributs malicieux
+		if ($GLOBALS['filtrer_javascript'] == -1) {
+			$html = safehtml($html);
+		}
+		return $html;
+	}
+	return '';
+}
